# IAR Tokenizer

The IAR (Iván Arias Rodríguez) Tokenizer is a tokenizer developed mainly for Spanish. It is able to divide a text in paragraphs, those in 
sentences, and each sentence in a list of tokens.

More information to be added in the future...